﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using LibreriaVirtual.Models;
using System.Web.Script.Serialization;
using System.Xml;


//Adición de un controlador vacio...
namespace LibreriaVirtual.Controllers
{
    public class HomeController : Controller
    {
      
        LibreriaVirtualEntities storeDB = new LibreriaVirtualEntities();

        //
        // GET: /Home/

        public ActionResult Index()
        {
            return View();
        }
  

        private List<Libros> GetLibrosNovedad()
        {
            return storeDB.Libros.Where( libro => libro.esNovedad == true).ToList();
        }

        public ActionResult GetCategorias() {
            var oCategorias = storeDB.Categorias.Where(cat => cat.IdCategoriaPadre == 1).ToList();
            XmlDocument xDoc = obtenerXMLCategorias(oCategorias);      

            ContentResult conResult = new ContentResult();
            string rutaWeb = System.Configuration.ConfigurationManager.AppSettings.Get("rutaWeb") + "Xslt/MenuCategorias.xslt";
            string sResult = LoadXslt(rutaWeb, xDoc);
            conResult.Content = sResult;
            return conResult;
        }

        public ActionResult GetNovedades() {
            var oLibros = GetLibrosNovedad();
            XmlDocument xDoc = obtenerXML(oLibros);        

            ContentResult conResult = new ContentResult();
            string rutaWeb = System.Configuration.ConfigurationManager.AppSettings.Get("rutaWeb") + "Xslt/LibrosNovedad.xslt";
            string sResult = LoadXslt(rutaWeb, xDoc);
            conResult.Content = sResult;
            return conResult;
        }

        public ActionResult BusquedaLibros(string sBusqueda)
        {
            ViewData["sBusqueda"] = sBusqueda;
            return View();
        }

        public ActionResult getBusquedaLibro(string sBusqueda)
        {
            sBusqueda = sBusqueda.Trim();
         
            var oLibros= storeDB.Libros.Where(libro => libro.Titulo.Contains(sBusqueda) || libro.Autor.Contains(sBusqueda)).ToList();

            XmlDocument xDoc = obtenerXML(oLibros);

            ContentResult conResult = new ContentResult();
            string rutaWeb = System.Configuration.ConfigurationManager.AppSettings.Get("rutaWeb") + "Xslt/LibrosNovedad.xslt";
            string sResult = LoadXslt(rutaWeb, xDoc);

            conResult.Content = sResult;
            return conResult;
        }

       

        public ActionResult getLibrosCategoria(int idCategoria)
        {
         
            var oLibros = storeDB.Libros.Where(libro => libro.IdCategoria==idCategoria).ToList();

            XmlDocument xDoc = obtenerXML(oLibros);

            ContentResult conResult = new ContentResult();
            string rutaWeb = System.Configuration.ConfigurationManager.AppSettings.Get("rutaWeb") + "Xslt/LibrosNovedad.xslt";
            string sResult = LoadXslt(rutaWeb, xDoc);

            conResult.Content = sResult;
            return conResult;
        }

        public XmlDocument obtenerXML(List<Libros> lLibros) {
           XmlDocument xDoc= new XmlDocument();
           xDoc.AppendChild(xDoc.CreateElement("DATOS"));
         
           XmlElement xRaiz = xDoc.DocumentElement;
            foreach (Libros i in lLibros){
                XmlElement xFila = xDoc.CreateElement("REGISTRO");
                xFila.SetAttribute("LIBRO_ID", Convert.ToString(i.IdLibro));
                xFila.SetAttribute("ISBN", i.ISBN);
                xFila.SetAttribute("AUTOR", i.Autor);
                xFila.SetAttribute("TITULO", i.Titulo);
                xRaiz.AppendChild(xFila);

            }
            return xDoc;
        }

        public XmlDocument obtenerXMLCategorias(List<Categorias> lCategoria)
        {
            XmlDocument xDoc = new XmlDocument();
            xDoc.AppendChild(xDoc.CreateElement("DATOS"));

            XmlElement xRaiz = xDoc.DocumentElement;
            foreach (Categorias i in lCategoria)
            {
                XmlElement xFila = xDoc.CreateElement("REGISTRO");
                xFila.SetAttribute("CATEGORIA_ID", Convert.ToString(i.IdCategoria));
                xFila.SetAttribute("NOMBRE", i.Nombre);
                xRaiz.AppendChild(xFila);
            }
            return xDoc;

        }
        public string LoadXslt(string  rutaXSLT , XmlDocument oXml) {

            System.Xml.Xsl.XslCompiledTransform xsDoc = new System.Xml.Xsl.XslCompiledTransform();
            System.Xml.Xsl.XsltSettings objXSLTSettings = new System.Xml.Xsl.XsltSettings(true, true);
            System.IO.StringWriter resultado = new System.IO.StringWriter();
            xsDoc.Load(rutaXSLT, objXSLTSettings, new System.Xml.XmlUrlResolver());
            xsDoc.Transform(oXml,null,resultado);
            return resultado.ToString();
            }
    }
}
