﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;


namespace LibreriaVirtual.Models
{
    public partial class CarritoCompra
    {
        private LibreriaVirtualEntities db = new LibreriaVirtualEntities();

       
        string ShoppingCarId { get; set; }
        public const string CarSessionKey = "CarId";


        // Metodo estatico para facilitar las llamadas desde el controlador
        // que devolvera un objeto shoppingCart
        public static CarritoCompra GetCar(Controller controller)
        {
            return GetCar(controller.HttpContext);
        }

        public static CarritoCompra GetCar(HttpContextBase context)
        {
            var car = new CarritoCompra();

            // establece el CartId desde session
            car.ShoppingCarId = car.GetCarId(context);

            return car;
        }

        // Devuelve y establece el CartID para esta session utilizando HttpContext.Session
        public string GetCarId(HttpContextBase context)
        {
            if (context.Session[CarSessionKey] == null)
            {
                if (!string.IsNullOrWhiteSpace(context.User.Identity.Name))
                {
                    // Usamos el identificador de usuario de sesion
                    context.Session[CarSessionKey] = context.User.Identity.Name;
                }
                else
                {
                    // Generamos un ID con la clase System.Guid
                    Guid tempCartId = Guid.NewGuid();
                    context.Session[CarSessionKey] = tempCartId.ToString();
                }
            }

            return context.Session[CarSessionKey].ToString();
        }

        public void AddToCar(Libros libro,int Tipo) //Tipo=> 1:Libro papel, 2: ebook
        {
            // Obtenemos la instancia para este cartId y courseId
            var carItem = db.Carrito.SingleOrDefault(c => c.IdCar == ShoppingCarId && c.IdLibro == libro.IdLibro);

            if (carItem == null)
            {
                
                var num=0;
                var numEbook=0;
                if (Tipo == 1) {
                    num=1;
                }else{
                    numEbook=1;
                }

                carItem = new Carrito
                {
                    IdLibro = libro.IdLibro,
                    IdCar = ShoppingCarId,
                    FechaCreado = DateTime.Now,
                    NumeroEbook=numEbook,
                    Numero=num
                };
                            
                db.Carrito.AddObject(carItem);
                                    
            }
            else
            {
                // Si el curso ya estaba reservado, aumentamos la cantidad
                if (Tipo == 1)
                {
                    carItem.Numero++;
                }
                else {
                    carItem.NumeroEbook++;
                }
                
            }

            db.SaveChanges();
        }

        public int RemoveFromCar(int id, int Tipo, int numLibros) //Tipo=> 1:Libro papel, 2: ebook
        {
            // Obtenemos el objeto cart para ese id
            var carItem = db.Carrito.Single(car => car.IdCar == ShoppingCarId && car.IdRecord == id);

            int itemCount = 0;
          
            if (carItem != null)
            {
                if (Tipo == 1) {
                    carItem.Numero =numLibros;
                    itemCount = carItem.Numero;
                    
                } else {
                        carItem.NumeroEbook =itemCount;
                        itemCount = carItem.NumeroEbook;
                }
                if (carItem.NumeroEbook == 0 && carItem.Numero == 0) {
                    db.Carrito.DeleteObject(carItem);
                }
                

                db.SaveChanges();
            }

            return itemCount;
        }

        public void deleteLibro(int id) {
            var carItem = db.Carrito.Single(car => car.IdCar == ShoppingCarId && car.IdRecord == id);
            db.Carrito.DeleteObject(carItem);
            db.SaveChanges();
        }

        public void EmptyCart()
        {
            // Borramos todos los objetos cart (para ese usuario -> ShoppingCartId)
            var cartItems = db.Carrito.Where(car => car.IdCar == ShoppingCarId);

            foreach (var carItem in cartItems)
            {
                db.Carrito.DeleteObject(carItem);
                
            }

            db.SaveChanges();
        }

        public List<Carrito> GetCarItems()
        {
            // Devuelve el listado de objetos cart (para ese usuario -> ShoppingCartId)
            return db.Carrito.Where(car => car.IdCar == ShoppingCarId).ToList();
                    
        }

        public int GetCount()
        {
            // Obtiene el numero de cada elemento del cart y lo suma
            int? count = (from carItems in db.Carrito
                          where carItems.IdCar == ShoppingCarId // del cart de este usuario
                          select (int?)carItems.Numero).Sum();

            // Si es null devuelve 0
            return count ?? 0;
        }

        public decimal GetTotal()
        {
            // Obtiene el precio total del cart
            // multiplicando la cantidad por el precio para cada item
            decimal? total = (from carItems in db.Carrito
                             where carItems.IdCar == ShoppingCarId // del cart de este usuario
                             select (int?) (carItems.Numero * carItems.Libros.Precio) + (carItems.NumeroEbook * carItems.Libros.PrecioEbook)).Sum();
            

            // si es null devuelve 0
            return total ?? 0;
        }


       
    }
}